@@ -9,6 +9,6 @@
 #  Software Foundation. See the file README for copying conditions.
 #
 
-from fields import AutoSlugField
+from autoslug.fields import AutoSlugField
 
 __all__ = ['AutoSlugField']
