@@ -1,6 +1,16 @@
 # -*- coding: utf-8 -*-
+#
+#  Copyright (c) 2008—2012 Andy Mikhailenko
+#
+#  This file is part of django-autoslug.
+#
+#  django-autoslug is free software under terms of the GNU Lesser
+#  General Public License version 3 (LGPLv3) as published by the Free
+#  Software Foundation. See the file README for copying conditions.
+#
 
 # django
+from django.core.exceptions import ImproperlyConfigured
 from django.db.models.fields import FieldDoesNotExist, DateField
 
 
@@ -16,6 +26,7 @@ def get_prepopulated_value(field, instance):
         attr = getattr(instance, field.populate_from)
         return callable(attr) and attr() or attr
 
+
 def generate_unique_slug(field, instance, slug, manager):
     """
     Generates unique slug by adding a number to given value until no model
@@ -59,6 +70,7 @@ def generate_unique_slug(field, instance, slug, manager):
 
         # ...next iteration...
 
+
 def get_uniqueness_lookups(field, instance, unique_with):
     """
     Returns a dict'able tuple of lookups to ensure uniqueness of a slug.
@@ -125,7 +137,40 @@ def get_uniqueness_lookups(field, instance, unique_with):
             else:
                 yield field_name, value
 
+
 def crop_slug(field, slug):
     if field.max_length < len(slug):
         return slug[:field.max_length]
     return slug
+
+
+try:
+    import translitcodec
+except ImportError:
+    pass
+else:
+    import re
+    PUNCT_RE = re.compile(r'[\t !"#$%&\'()*\-/<=>?@\[\\\]^_`{|},.]+')
+
+    def translitcodec_slugify(codec):
+        def _slugify(value, delim=u'-', encoding=''):
+            """
+            Generates an ASCII-only slug.
+
+            Borrowed from http://flask.pocoo.org/snippets/5/
+            """
+            if encoding:
+                encoder = "%s/%s" % (codec, encoding)
+            else:
+                encoder = codec
+            result = []
+            for word in PUNCT_RE.split(value.lower()):
+                word = word.encode(encoder)
+                if word:
+                    result.append(word)
+            return unicode(delim.join(result))
+        return _slugify
+
+    translit_long = translitcodec_slugify("translit/long")
+    translit_short = translitcodec_slugify("translit/short")
+    translit_one = translitcodec_slugify("translit/one")
